Introduction
============

.. image:: https://badge.fury.io/py/bottle-gui.png
    :target: http://badge.fury.io/py/bottle-gui

.. image:: https://pypip.in/d/bottle-gui/badge.png
        :target: https://crate.io/packages/bottle-gui?version=latest

This package is used to vizualize services in `Bottle <http://bottlepy.org>`_
web framework.

Documentation
-------------

Full module documentation and description can be found at Read the Docs:

- http://bottle-gui.readthedocs.org/
